(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.editor.InspectorControls;
    var RichText = wp.editor.RichText;
    var URLText = wp.editor.URLInput;
    var Fragment = wp.element.Fragment;
    var MediaUpload = wp.editor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
    var __ = wp.i18n.__;
	var plugin_url = cwp_options.plugin_url;

    var _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };

    function _toConsumableArray(arr) {
        if (Array.isArray(arr)) {
            for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) {
                arr2[i] = arr[i];
            }
            return arr2;
        } else {
            return Array.from(arr);
        }
    }

    function _LinkMove(e, t, n) {
        var r = e.slice(0);
        if (n >= r.length) {
            for (var o = n - r.length; 1 + o--;) {
                r.push(void 0);
            }
        }
        return r.splice(n, 0, r.splice(t, 1)[0]), r;
    }

    wp.blocks.registerBlockType('cwp/classifieds-tiles', {
        title: __('Classifieds Tiles', 'cosmic-blocks'),
		keywords: [
			'classifieds tiles',
			__('classifieds cards', 'cosmic-blocks'),
			__('advertisements tiles', 'cosmic-blocks'),
		],
        icon: {
            background: "#16A3FF",
            foreground: "#FFFFFF",
            src: "calendar-alt"
        },
        category: 'cwp-blocks',
        attributes: {
            blockID: {
                type: 'string',
                default: ''
            },
            columns: {
                type: "number",
                default: 3
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
            backgroundType: {
                type: "string",
                default: 'color'
            },
            backgroundTextColor: {
                type: "string",
                default: ''
            },
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
            paddingBeforeIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterItems: {
                type: 'number',
                default: 50
            },
            introsection: {
                type: 'string',
                default: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            },
            boxradius: {
                type: "number",
                default: 0
            },
			boxradiusfix: {
				type: 'boolean',
				default: false
			},
            boxpadding: {
                type: "number",
                default: 0
            },
			boxpaddingfix: {
				type: 'boolean',
				default: false
			},
            link: {
                type: 'array',
                default: [{
                    mediaID: "",
                    mediaURL: "",
                    price: "",
					pricecolor: "#ffffff",
                    pricebgcolor: "#ff9900",
                    title: "",
					text: "",
                    email: "",
                    phone: "",
                    location: "",
					buttonText: __('Read more', 'cosmic-blocks'),
					buttonURL: "",
					buttonStyle: "cwp-button cwp-button-primary",
					buttonTarget: "_self",
					buttonAltText: __('Read more', 'cosmic-blocks'),
					buttonAltURL: "",
					buttonAltStyle: "cwp-button cwp-button-secondary",
					buttonAltTarget: "_self",
                    color: "",
                    textcolor: ""
                },
				{
					mediaID: "",
                    mediaURL: "",
                    price: "",
					pricecolor: "#ffffff",
                    pricebgcolor: "#ff9900",
                    title: "",
					text: "",
                    email: "",
                    phone: "",
                    location: "",
					buttonText: __('Read more', 'cosmic-blocks'),
					buttonURL: "",
					buttonStyle: "cwp-button cwp-button-primary",
					buttonTarget: "_self",
					buttonAltText: __('Read more', 'cosmic-blocks'),
					buttonAltURL: "",
					buttonAltStyle: "cwp-button cwp-button-secondary",
					buttonAltTarget: "_self",
                    color: "",
                    textcolor: ""
				},
				{
					mediaID: "",
                    mediaURL: "",
                    price: "",
					pricecolor: "#ffffff",
                    pricebgcolor: "#ff9900",
                    title: "",
					text: "",
                    email: "",
                    phone: "",
                    location: "",
					buttonText: __('Read more', 'cosmic-blocks'),
					buttonURL: "",
					buttonStyle: "cwp-button cwp-button-primary",
					buttonTarget: "_self",
					buttonAltText: __('Read more', 'cosmic-blocks'),
					buttonAltURL: "",
					buttonAltStyle: "cwp-button cwp-button-secondary",
					buttonAltTarget: "_self",
                    color: "",
                    textcolor: ""
				}]
            }
        },
        getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
            var attributes = props.attributes;

            // override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.boxradius = -1;
				attributes.boxradiusfix = true;
				attributes.boxpadding = -1;
				attributes.boxpaddingfix = true;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}

            var items = attributes.link;
            var cwpUpdateLink = function(value, index) {
                var _props2 = props;
                var attributes = _props2.attributes;
                var setAttributes = _props2.setAttributes;
                var items = attributes.link;

                var newItems = items.map(function(item, thisIndex) {
                    if (index === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    link: newItems
                });
            };

            var solidColorPreset = el(ColorPalette, {
                value: attributes.solidColor,
                onChange: function(e) {
                    props.setAttributes({
                        solidColor: e
                    });
                },
                colors: [{
                    color: "#ffffff",
                    name: "white"
                }, {
                    color: "#00d1b2",
                    name: "teal"
                }, {
                    color: "#3373dc",
                    name: "royal blue"
                }, {
                    color: "#209cef",
                    name: "sky blue"
                }, {
                    color: "#22d25f",
                    name: "green"
                }]
            });
            var backgroundTextColorPreset = el(ColorPalette, {
                value: attributes.backgroundTextColor,
                onChange: function(e) {
                    props.setAttributes({
                        backgroundTextColor: e
                    });
                },
                colors: [{
                    color: "#ffffff",
                    name: "white"
                }, {
                    color: "#333333",
                    name: "dark"
                }, {
                    color: "#000000",
                    name: "black"
                }, {
                    color: "#209cef",
                    name: "sky blue"
                }, {
                    color: "#22d25f",
                    name: "green"
                }]
            });
            var gradientPreset = el(SelectControl, {
                label: __('Gradients', 'cosmic-blocks'),
                options: gradient_options.map(function(e) {
                    return {
                        value: e.colors,
                        label: e.name
                    };
                }),
                value: attributes.gradient,
                onChange: function(e) {
                    props.setAttributes({
                        gradient: e
                    });
                }
            });
            var back_style = function() {
                var s = {};
                if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
                    s = {
                        background: attributes.solidColor
                    };
                } else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
                    s = {
                        background: "linear-gradient(to bottom, " + attributes.gradient + ")"
                    };
                } else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
                    s = {
                        background: "url( " + attributes.backgroundMediaURL + " )",
                        backgroundSize: "cover",
                        backgroundPosition: "center"
                    };
                }
                return s;
            };
            var back_text_style = function() {
                var s = {};
                if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
                    s = {
                        color: attributes.backgroundTextColor
                    };
                }
                return s;
            };
            var box_style = function() {
				var s = {};
				if(attributes.boxradiusfix === true && attributes.boxradius >= 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				else if(attributes.boxradius > 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				if(attributes.boxpaddingfix === true && attributes.boxpadding >= 0)
				{
					s.padding = attributes.boxpadding;
				}
				else if(attributes.boxpadding > 0)
				{
					s.padding = attributes.boxpadding;
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return [
                el(
                    Fragment,
                    null,
                    el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
                        el(wp.components.PanelBody, {
                                title: __('Intro', 'cosmic-blocks'),
                                className: 'cwp-inspector-intro',
                                initialOpen: false
                            },
                            el(SelectControl, {
                                label: __('Enable/disable', 'cosmic-blocks'),
                                value: attributes.introsection,
                                options: [{
                                        label: __('Disabled', 'cosmic-blocks'),
                                        value: 'disabled'
                                    },
                                    {
                                        label: __('Enabled', 'cosmic-blocks'),
                                        value: 'enabled'
                                    }
                                ],
                                onChange: function onChange(value) {
                                    props.setAttributes({
                                        introsection: value
                                    });
                                }
                            }),
                            attributes.introsection === 'enabled' ? el('p', {}, __('Intro text color', 'cosmic-blocks')) : '',
                            attributes.introsection === 'enabled' ? backgroundTextColorPreset : '',
                            attributes.introsection === 'enabled' ? el(RangeControl, {
                                label: __('Padding after intro text', 'cosmic-blocks'),
                                value: attributes.paddingAfterIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }) : '',
                        ),
                        el(wp.components.PanelBody, {
                                title: __('Layout', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: false
                            },
                            el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el(RangeControl, {
                                label: __('Padding bottom', 'cosmic-blocks'),
                                value: attributes.paddingAfterItems,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterItems: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, "Click the image to edit or upprice"), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
                        ),
                        el(wp.components.PanelBody, {
                                title: __('Items', 'cosmic-blocks'),
                                className: 'cwp-inspector-items',
                                initialOpen: true
                            },
                            el(RangeControl, {
                                label: __('Items per row', 'cosmic-blocks'),
                                value: attributes.columns,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        columns: e
                                    });
                                },
                                min: 1,
                                max: 4
                            }),
                            el(SelectControl, {
                                label: __('Image size', 'cosmic-blocks'),
                                value: attributes.thumbnailSize,
                                options: thumbnail_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(value) {
                                    var thumb = value;
                                    jQuery.post(ajaxurl, {
                                        action: 'cosmic_blocks_thumbnail_helper',
                                        thumb: thumb,
                                        items: items
                                    }, function(response) {
                                        response.map(function(item) {
                                            attributes.link[item.index].mediaURL = (item.thumb.src !== '' && item.thumb.src !== undefined) ? item.thumb.src : item.full.src;
                                        });
                                        return props.setAttributes({
                                            thumbnailSize: thumb
                                        });
                                    }, 'json');
                                }
                            }),
                            el(RangeControl, {
								label: __('Items border radius', 'cosmic-blocks'),
								value: attributes.boxradius,
								onChange: function(e) {
									return props.setAttributes({
										boxradius: e,
										boxradiusfix: true
									});
								},
								min: -1,
								max: 50
							}),
							el(RangeControl, {
								label: __('Items padding', 'cosmic-blocks'),
								value: attributes.boxpadding,
								onChange: function(e) {
									return props.setAttributes({
										boxpadding: e,
										boxpaddingfix: true
									});
								},
								min: -1,
								max: 50
							})
                        ),
                        el(wp.components.PanelBody, {
                                title: __('Animation', 'cosmic-blocks'),
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el(SelectControl, {
                                label: __('Animation', 'cosmic-blocks'),
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el(TextControl, {
                                label: __('Animation Delay', 'cosmic-blocks'),
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: __('Enter in milliseconds', 'cosmic-blocks')
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
                                allowReset: false,
                                initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            })
                        )
                    ),
                    el('div', {
                            id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-backend-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
                                style: box_padding()
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
                                    style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
                                            formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
                                            formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
                                            formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        }),
                                    ),
                                )
                            ) : '',
                            el('div', {
                                    className: 'cwp-main-wrapper cwp-' + attributes.columns + '-column'
                                },
                                items.map(function(item, index) {
                                    var block_back_style = function() {
                                        var s = {};
                                        if (item.color !== '' && item.color !== undefined) {
                                            s = {
                                                background: item.color
                                            };
                                        }
                                        return s;
                                    };
                                    var block_text_style = function() {
                                        var s = {};
                                        if (item.textcolor !== '' && item.textcolor !== undefined) {
                                            s = {
                                                color: item.textcolor
                                            };
                                        }
                                        return s;
                                    };
									var price_color_style = function() {
                                        var s = {};
                                        if (item.pricecolor !== '' && item.pricecolor !== undefined) {
                                            s.color = item.pricecolor;
                                        }
										if (item.pricebgcolor !== '' && item.pricebgcolor !== undefined) {
                                            s.background = item.pricebgcolor;
                                        }
                                        return s;
                                    };
									
                                    return el(
                                        Fragment, {
                                            key: index
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap'
                                            },
                                            el('div', {
                                                    className: 'cwp-meta-options'
                                                },
                                                el('div', {
                                                        className: 'cwp-element-bgcolor-main'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-drag-item cwp-option-bgcolor'
                                                        },
                                                        el('i', {
                                                            className: 'fa fa-paint-brush'
                                                        }),
                                                        el(ColorPalette, {
                                                            value: item.color,
                                                            onChange: function(e) {
                                                                return cwpUpdateLink({
                                                                    color: e
                                                                }, index);
                                                            }
                                                        })
                                                    )
                                                ),
                                                el('div', {
                                                        className: 'cwp-element-textcolor-main'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-drag-item cwp-option-textcolor'
                                                        },
                                                        el('i', {
                                                            className: 'fa fa-font',
                                                            style: block_text_style()
                                                        }),
                                                        el(ColorPalette, {
                                                            value: item.textcolor,
                                                            onChange: function(e) {
                                                                return cwpUpdateLink({
                                                                    textcolor: e
                                                                }, index);
                                                            }
                                                        })
                                                    )
                                                ),
												el('div', {
													className: 'cwp-drag-item cwp-drag-item-wrapper'
												}, el('span', {
														className: "dashicons dashicons-move"
													},
													el('div', {
															className: 'cwp-drag-item-container'
														},
														el('div', {
																className: 'cwp-drag-item-container-inner'
															},
															el('div', {
																className: 'cwp-drag-item-move cwp-drag-item-left',
																onClick: function() {
																	var old_index = index,
																		next_index = index - 1,
																		new_items = _LinkMove(items, old_index, next_index);
																	return props.setAttributes({
																		link: new_items
																	});
																}
															}, el('div', null, el('span', {
																className: "dashicons dashicons-arrow-left-alt2"
															}))),
															el('div', {
																className: 'cwp-drag-item-upanddown'
																},
																	el('div', {
																	className: 'cwp-drag-item-move cwp-drag-item-up',
																	onClick: function() {
																		var old_index = index,
																			next_index = index - attributes.columns,
																			new_items = _LinkMove(items, old_index, next_index);
																		return props.setAttributes({
																			link: new_items
																		});
																	}
																}, el('div', null, el('span', {
																	className: "dashicons dashicons-arrow-up-alt2"
																}))),
																el('div', {
																	className: 'cwp-drag-item-move cwp-drag-item-down',
																	onClick: function() {
																		var old_index = index,
																			next_index = index + attributes.columns,
																			new_items = _LinkMove(items, old_index, next_index);
																		return props.setAttributes({
																			link: new_items
																		});
																	}
																}, el('div', null, el('span', {
																	className: "dashicons dashicons-arrow-down-alt2"
																}))),
															),
															el('div', {
																className: 'cwp-drag-item-move cwp-drag-item-right',
																onClick: function() {
																	var old_index = index,
																		next_index = index + 1,
																		new_items = _LinkMove(items, old_index, next_index);
																	return props.setAttributes({
																		link: new_items
																	});
																}
															}, el('div', null, el('span', {
																className: "dashicons dashicons-arrow-right-alt2"
															}))),
														)
													))
												),
												el('div', {
													className: 'cwp-remove',
													title: __('Remove', 'cosmic-blocks'),
													onClick: function removeClick() {
														if (confirm(__('Are you sure?', 'cosmic-blocks'))) {
															return props.setAttributes({
																link: items.filter(function(cItem, cIndex) {
																	return cIndex !== index;
																})
															});
														}
													}
												}, el('div', null, el('span', {
													className: "dashicons dashicons-trash"
												}))),
                                            ),
                                            el('div', {
                                                    className: 'cwp-content-wrap' + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : ''),
                                                    style: Object.assign(block_back_style(), box_style())
                                                },
                                                el('div', {
                                                        className: 'cwp-list-content-wrap'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-list-content-wrap-inner'
                                                        },
                                                        el('div', {
                                                                className: 'cwp-list-content-wrap-image'
                                                            },
															el('div', {
																	className: item.mediaID ? 'cwp-image image-active' : 'cwp-image image-inactive'
																},
																el(MediaUpload, {
																	onSelect: function(media) {
																		if (media.id !== '' && media.id !== undefined) {
																			wp.apiFetch({
																				path: "/wp/v2/media/" + media.id
																			}).then((response) => {
																				var newMediaUrl = response.media_details.sizes.full.source_url;
																				if (response.media_details.sizes[attributes.thumbnailSize] !== '' && response.media_details.sizes[attributes.thumbnailSize] !== undefined) {
																					newMediaUrl = response.media_details.sizes[attributes.thumbnailSize].source_url;
																				}

																				return cwpUpdateLink({
																					mediaID: media.id,
																					mediaURL: newMediaUrl
																				}, index);
																			});
																		}
																	},
																	type: 'image',
																	value: item.mediaID,
																	render: function(obj) {
																		if (item.mediaID !== '' && item.mediaID !== undefined) {
																			return el(wp.components.Button, {
																				className: 'image-button',
																				onClick: obj.open
																			}, el('img', {
																				src: item.mediaURL
																			}));
																		} else {
																			return el(wp.components.Button, {
																				className: 'button button-large',
																				onClick: obj.open
																			}, __('Upload Image', 'cosmic-blocks'));
																		}
																	}
																}),
																item.mediaID && el('div', {
																		className: 'remove-image',
																		title: __('Remove Image', 'cosmic-blocks'),
																		onClick: function() {
																			if (confirm(__('Are you sure?', 'cosmic-blocks'))) {
																				return cwpUpdateLink({
																					mediaID: void 0,
																					mediaURL: void 0
																				}, index);
																			}
																		}
																	},
																	el('span', {
																		className: "dashicons dashicons-no-alt"
																	})
																)
															),
															el('div', {
																className: 'cwp-color-select',
																	style: {
																		marginTop: '10px'
																	}
																},
																el('div', {
																		className: 'cwp-color-select-label',
																		title: __('Price Color Settings', 'cosmic-blocks')
																	},
																	__('Price Color Settings', 'cosmic-blocks')
																),
																el('div', {
																		className: 'cwp-color-select-item cwp-color-select-bgcolor'
																	},
																	el('i', {
																		className: 'fa fa-paint-brush'
																	}),
																	el(ColorPalette, {
																		value: item.pricebgcolor,
																		onChange: function(e) {
																			return cwpUpdateLink({
																				pricebgcolor: e
																			}, index);
																		}
																	})
																),
																el('div', {
																		className: 'cwp-color-select-item cwp-color-select-textcolor'
																	},
																	el('i', {
																		className: 'fa fa-font'
																	}),
																	el(ColorPalette, {
																		value: item.pricecolor,
																		onChange: function(e) {
																			return cwpUpdateLink({
																				pricecolor: e
																			}, index);
																		}
																	})
																)
															),
															el(RichText, {
																tagName: 'div',
																className: 'cwp-price',
																placeholder: __('$2500', 'cosmic-blocks'),
																keepPlaceholderOnFocus: true,
																value: item.price,
																isSelected: attributes.isSelected,
																formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
																style: price_color_style(),
																onChange: function onChange(value) {
																	return cwpUpdateLink({
																		price: value
																	}, index);
																}
															})
														),
                                                        el('div', {
                                                                className: 'cwp-list-content-wrap-content'
                                                            },
															el('div', {
																	className: 'cwp-list-content-wrap-content-title'
																},
																el('div', {
																		className: 'cwp-list-content-wrap-content-title-wrap'
																	},
																	el(RichText, {
																		tagName: 'h3',
																		placeholder: __('Title', 'cosmic-blocks'),
																		keepPlaceholderOnFocus: true,
																		value: item.title,
																		isSelected: attributes.isSelected,
																		formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
																		style: block_text_style(),
																		onChange: function onChange(value) {
																			return cwpUpdateLink({
																				title: value
																			}, index);
																		}
																	})
																),
																el('div', {
																		className: 'cwp-list-content-wrap-content-title-location'
																	},
																	el(RichText, {
																		tagName: 'p',
																		placeholder: __('New York', 'cosmic-blocks'),
																		keepPlaceholderOnFocus: true,
																		value: item.location,
																		isSelected: attributes.isSelected,
																		formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
																		style: block_text_style(),
																		onChange: function onChange(value) {
																			return cwpUpdateLink({
																				location: value
																			}, index);
																		}
																	})
																)
															),
															el('div', {
																	className: 'cwp-list-content-wrap-content-text'
																},
																el(RichText, {
																	tagName: 'p',
																	placeholder: 'Voluptatibus hic amet modi est aut non. Odit dolores fugiat qui assumenda debitis non eos. Non eius ab blanditiis aut sit.',
																	keepPlaceholderOnFocus: true,
																	value: item.text,
																	isSelected: attributes.isSelected,
																	formattingControls: ['bold', 'italic', 'strikethrough', 'link'],
																	style: block_text_style(),
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			text: value
																		}, index);
																	}
																})
															),
															el('div', {
																	className: 'cwp-list-content-wrap-meta'
																},
																el('div', {
																		className: 'cwp-list-content-wrap-meta-second'
																	},
																	el(TextControl, {
																		placeholder: __('E-Mail', 'cosmic-blocks'),
																		keepPlaceholderOnFocus: true,
																		value: item.email,
																		onChange: function onChange(value) {
																			return cwpUpdateLink({
																				email: value
																			}, index);
																		}
																	})
																),
																el('div', {
																		className: 'cwp-list-content-wrap-meta-second'
																	},
																	el(TextControl, {
																		placeholder: __('Phone', 'cosmic-blocks'),
																		keepPlaceholderOnFocus: true,
																		value: item.phone,
																		onChange: function onChange(value) {
																			return cwpUpdateLink({
																				phone: value
																			}, index);
																		}
																	})
																)
															),
															el('div', {
																	className: 'cwp-list-content-wrap-buttons'
																},
																el(URLText, {
																	value: item.buttonURL,
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonURL: value
																		}, index);
																	}
																}),
																item.buttonURL !== '' && item.buttonURL !== undefined ? el(SelectControl, {
																	value: item.buttonStyle,
																	options: button_options.map(function(e) {
																		return {
																			value: e.value,
																			label: e.label
																		};
																	}),
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonStyle: value
																		}, index);
																	}
																}) : '',
																item.buttonURL !== '' && item.buttonURL !== undefined ? el(SelectControl, {
																	value: item.buttonTarget,
																	options: [{
																			label: __('Open link in same window', 'cosmic-blocks'),
																			value: '_self'
																		},
																		{
																			label: __('Open link in new window', 'cosmic-blocks'),
																			value: '_blank'
																		}
																	],
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonTarget: value
																		}, index);
																	}
																}) : '',
																item.buttonURL !== '' && item.buttonURL !== undefined ? el(RichText, {
																	tagName: 'div',
																	className: item.buttonStyle,
																	placeholder: '',
																	keepPlaceholderOnFocus: true,
																	value: item.buttonText,
																	isSelected: attributes.isSelected,
																	formattingControls: [],
																	multiline: false,
																	formattingControls: [],
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonText: value
																		}, index);
																	}
																}) : '',
																el(URLText, {
																	value: item.buttonAltURL,
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonAltURL: value
																		}, index);
																	}
																}),
																item.buttonAltURL !== '' && item.buttonAltURL !== undefined ? el(SelectControl, {
																	value: item.buttonAltStyle,
																	options: button_options.map(function(e) {
																		return {
																			value: e.value,
																			label: e.label
																		};
																	}),
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonAltStyle: value
																		}, index);
																	}
																}) : '',
																item.buttonAltURL !== '' && item.buttonAltURL !== undefined ? el(SelectControl, {
																	value: item.buttonAltTarget,
																	options: [{
																			label: __('Open link in same window', 'cosmic-blocks'),
																			value: '_self'
																		},
																		{
																			label: __('Open link in new window', 'cosmic-blocks'),
																			value: '_blank'
																		}
																	],
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonAltTarget: value
																		}, index);
																	}
																}) : '',
																item.buttonAltURL !== '' && item.buttonAltURL !== undefined ? el(RichText, {
																	tagName: 'div',
																	className: item.buttonAltStyle,
																	placeholder: '',
																	keepPlaceholderOnFocus: true,
																	value: item.buttonAltText,
																	isSelected: attributes.isSelected,
																	formattingControls: [],
																	multiline: false,
																	formattingControls: [],
																	onChange: function onChange(value) {
																		return cwpUpdateLink({
																			buttonAltText: value
																		}, index);
																	}
																}) : ''
															)
														)
                                                    )
                                                )
                                            )
                                        )
                                    );
                                })
                            )
                        )
                    ),

                    /** Front View **/

                    el('div', {
                            id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-front-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner',
                                style: box_padding(),
                                "data-scroll-class": attributes.animationStyle,
                                "data-scroll-delay": attributes.animationDelay,
                                "data-scroll-threshold": attributes.threshold
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
                                    style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('h3', {
                                            style: back_text_style()
                                        },
                                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
                                            RichText.Content, {
                                                tagName: '',
                                                value: attributes.introtitle
                                            }
                                        ) : '',
                                        (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
                                            RichText.Content, {
                                                tagName: 'span',
                                                value: attributes.introsubtitle
                                            }
                                        ) : '',
                                    ),
                                ) : '',
                                (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(
                                            RichText.Content, {
                                                tagName: 'p',
                                                value: attributes.introduction,
                                                style: back_text_style()
                                            }
                                        ),
                                    ),
                                ) : '',
                            ) : '',
                            el('div', {
                                    className: 'cwp-main-wrapper cwp-' + attributes.columns + '-column'
                                },
                                items.map(function(item, index) {
                                    var block_back_style = function() {
                                        var s = {};
                                        if (item.color !== '' && item.color !== undefined) {
                                            s = {
                                                background: item.color
                                            };
                                        }
                                        return s;
                                    };
                                    var block_text_style = function() {
                                        var s = {};
                                        if (item.textcolor !== '' && item.textcolor !== undefined) {
                                            s = {
                                                color: item.textcolor
                                            };
                                        }
                                        return s;
                                    };
									var price_color_style = function() {
                                        var s = {};
                                        if (item.pricecolor !== '' && item.pricecolor !== undefined) {
                                            s.color = item.pricecolor;
                                        }
										if (item.pricebgcolor !== '' && item.pricebgcolor !== undefined) {
                                            s.background = item.pricebgcolor;
                                        }
                                        return s;
                                    };
                                    return el(
                                        Fragment, {
                                            key: index
                                        },
                                        el('div', {
                                                className: index % 2 !== 0 && (item.title !== '' || item.text !== '') ? 'cwp-inner-wrap cwp-inner-odd' : 'cwp-inner-wrap cwp-inner-even'
                                            },
                                            el('div', {
                                                    className: 'cwp-content-wrap' + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : ''),
                                                    style: Object.assign(block_back_style(), box_style())
                                                },
                                                el('div', {
                                                        className: 'cwp-list-content-wrap'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-list-content-wrap-inner'
                                                        },
                                                        el('div', {
                                                                className: 'cwp-list-content-wrap-image'
                                                            },
															item.mediaURL !== '' && item.mediaURL !== undefined ? el('div', {
																	className: 'cwp-image'
																},
																el('img', {
																	src: item.mediaURL
																}),
															) : el('div', {
																className: 'cwp-image'
															}, el('img', {
																src: plugin_url + '/assets/images/image.png'
															})),
															item.price !== '' && item.price !== undefined ? el(RichText.Content, {
																tagName: 'div',
																className: 'cwp-price cwp-price-front',
																value: item.price,
																style: price_color_style()
															}) : '',
														),
                                                        el('div', {
                                                                className: 'cwp-list-content-wrap-content'
                                                            },
															el('div', {
																	className: 'cwp-list-content-wrap-content-title'
																},
																el('div', {
																		className: 'cwp-list-content-wrap-content-title-wrap'
																	},
																	el(RichText.Content, {
																		tagName: 'h3',
																		value: item.title,
																		style: block_text_style()
																	})
																),
																item.location !== '' && item.location !== undefined ? el('div', {
																		className: 'cwp-list-content-wrap-content-title-location'
																	},
																	el(RichText.Content, {
																		tagName: 'p',
																		value: item.location,
																		style: block_text_style()
																	})
																) : ''
															),
															el('div', {
																	className: 'cwp-list-content-wrap-content-text'
																},
																el(RichText.Content, {
																	tagName: 'p',
																	value: item.text,
																	isSelected: attributes.isSelected,
																	style: block_text_style()
																})
															),
															el('div', {
																	className: 'cwp-list-content-wrap-meta'
																},
																item.email !== '' && item.email !== undefined ? el('div', {
																		className: 'cwp-list-content-wrap-meta-second'
																	},
																	el('i', {
																		className: 'fa fa-envelope'
																	}),
																	el('a', {
																		href: 'mailto:' + item.email,
																		style: block_text_style()
																	}, item.email)
																) : '',
																item.phone !== '' && item.phone !== undefined ? el('div', {
																		className: 'cwp-list-content-wrap-meta-second'
																	},
																	el('i', {
																		className: 'fa fa-phone'
																	}),
																	el('a', {
																		href: 'tel:' + item.phone,
																		style: block_text_style()
																	}, item.phone)
																) : ''
															),
															(item.buttonURL !== '' && item.buttonText.length > 0 && item.buttonText !== '') || (item.buttonAltURL !== '' && item.buttonAltText.length > 0 && item.buttonAltText !== '') ? el('div', {
																	className: 'cwp-buttons-wrap'
																},
																item.buttonURL !== '' && item.buttonText.length > 0 && item.buttonText !== '' ? el('div', {
																		className: 'cwp-button-wrap'
																	},
																	el(RichText.Content, {
																		tagName: 'a',
																		value: item.buttonText,
																		className: item.buttonStyle,
																		href: item.buttonURL,
																		target: item.buttonTarget,
																		rel: item.buttonTarget ? 'noopener noreferrer' : null
																	})
																) : '',
																item.buttonAltURL !== '' && item.buttonAltText.length > 0 && item.buttonAltText !== '' ? el('div', {
																		className: 'cwp-button-wrap'
																	},
																	el(RichText.Content, {
																		tagName: 'a',
																		value: item.buttonAltText,
																		className: item.buttonAltStyle,
																		href: item.buttonAltURL,
																		target: item.buttonAltTarget,
																		rel: item.buttonAltTarget ? 'noopener noreferrer' : null
																	})
																) : ''
															) : ''
														)
                                                    )
                                                )
                                            )
                                        )
                                    );
                                })
                            )
                        )
                    ),

                    /** Front View **/
                    el('div', {
                            className: "cwp-add-new"
                        },
                        el(
                            "button", {
                                className: "button button-large button-primary",
                                onClick: function NewClick() {
                                    return props.setAttributes({
                                        link: [].concat(_toConsumableArray(items), [{
                                            mediaID: "",
											mediaURL: "",
											price: "",
											pricecolor: "#ffffff",
											pricebgcolor: "#ff9900",
											title: "",
											text: "",
											email: "",
											phone: "",
											location: "",
											buttonText: __('Read more', 'cosmic-blocks'),
											buttonURL: "",
											buttonStyle: "cwp-button cwp-button-primary",
											buttonTarget: "_self",
											buttonAltText: __('Read more', 'cosmic-blocks'),
											buttonAltURL: "",
											buttonAltStyle: "cwp-button cwp-button-secondary",
											buttonAltTarget: "_self",
											color: "",
											textcolor: ""
                                        }])
                                    });
                                }
                            },
                            __('Add', 'cosmic-blocks')
                        )
                    )
                )
            ];
        },
        save: function(props) {
            var attributes = props.attributes;

			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}

            var items = attributes.link;
			var plugin_url = cwp_options.plugin_url;
            var back_style = function() {
                var s = {};
                if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
                    s = {
                        background: attributes.solidColor
                    };
                } else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
                    s = {
                        background: "linear-gradient(to bottom, " + attributes.gradient + ")"
                    };
                } else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
                    s = {
                        background: "url( " + attributes.backgroundMediaURL + " )",
                        backgroundSize: "cover",
                        backgroundPosition: "center"
                    };
                }
                return s;
            };
            var back_text_style = function() {
                var s = {};
                if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
                    s = {
                        color: attributes.backgroundTextColor
                    };
                }
                return s;
            };
            var box_style = function() {
				var s = {};
				if(attributes.boxradiusfix === true && attributes.boxradius >= 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				else if(attributes.boxradius > 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				if(attributes.boxpaddingfix === true && attributes.boxpadding >= 0)
				{
					s.padding = attributes.boxpadding;
				}
				else if(attributes.boxpadding > 0)
				{
					s.padding = attributes.boxpadding;
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return el('div', {
					id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
					className: attributes.container + ' cwp-common-main-wrap' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
					style: back_style()
				},
				el('div', {
						className: 'cwp-common-main-wrap-inner',
						style: box_padding(),
						"data-scroll-class": attributes.animationStyle,
						"data-scroll-delay": attributes.animationDelay,
						"data-scroll-threshold": attributes.threshold
					},
					attributes.introsection === 'enabled' ? el('div', {
							className: 'cwp-main-intro',
							style: attributes.paddingAfterIntro >= 0 ? {
								paddingBottom: attributes.paddingAfterIntro
							} : {}
						},
						(attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
								className: 'cwp-intro-title'
							},
							el('h3', {
									style: back_text_style()
								},
								(attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
									RichText.Content, {
										tagName: '',
										value: attributes.introtitle
									}
								) : '',
								(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
									RichText.Content, {
										tagName: 'span',
										value: attributes.introsubtitle
									}
								) : '',
							),
						) : '',
						(attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
								className: 'cwp-intro-introduction'
							},
							el('div', {
									className: 'cwp-intro-input'
								},
								el(
									RichText.Content, {
										tagName: 'p',
										value: attributes.introduction,
										style: back_text_style()
									}
								),
							),
						) : '',
					) : '',
					el('div', {
							className: 'cwp-main-wrapper cwp-' + attributes.columns + '-column'
						},
						items.map(function(item, index) {
							var block_back_style = function() {
								var s = {};
								if (item.color !== '' && item.color !== undefined) {
									s = {
										background: item.color
									};
								}
								return s;
							};
							var block_text_style = function() {
								var s = {};
								if (item.textcolor !== '' && item.textcolor !== undefined) {
									s = {
										color: item.textcolor
									};
								}
								return s;
							};
							var price_color_style = function() {
								var s = {};
								if (item.pricecolor !== '' && item.pricecolor !== undefined) {
									s.color = item.pricecolor;
								}
								if (item.pricebgcolor !== '' && item.pricebgcolor !== undefined) {
									s.background = item.pricebgcolor;
								}
								return s;
							};
							return el(
								Fragment, {
									key: index
								},
								el('div', {
										className: index % 2 !== 0 && (item.title !== '' || item.text !== '') ? 'cwp-inner-wrap cwp-inner-odd' : 'cwp-inner-wrap cwp-inner-even'
									},
									el('div', {
											className: 'cwp-content-wrap' + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : ''),
											style: Object.assign(block_back_style(), box_style())
										},
										el('div', {
												className: 'cwp-list-content-wrap'
											},
											el('div', {
													className: 'cwp-list-content-wrap-inner'
												},
												el('div', {
														className: 'cwp-list-content-wrap-image'
													},
													item.mediaURL !== '' && item.mediaURL !== undefined ? el('div', {
															className: 'cwp-image'
														},
														el('img', {
															src: item.mediaURL
														}),
													) : el('div', {
														className: 'cwp-image'
													}, el('img', {
														src: plugin_url + '/assets/images/image.png'
													})),
													item.price !== '' && item.price !== undefined ? el(RichText.Content, {
														tagName: 'div',
														className: 'cwp-price cwp-price-front',
														value: item.price,
														style: price_color_style()
													}) : '',
												),
												el('div', {
														className: 'cwp-list-content-wrap-content'
													},
													el('div', {
															className: 'cwp-list-content-wrap-content-title'
														},
														el('div', {
																className: 'cwp-list-content-wrap-content-title-wrap'
															},
															el(RichText.Content, {
																tagName: 'h3',
																value: item.title,
																style: block_text_style()
															})
														),
														item.location !== '' && item.location !== undefined ? el('div', {
																className: 'cwp-list-content-wrap-content-title-location'
															},
															el(RichText.Content, {
																tagName: 'p',
																value: item.location,
																style: block_text_style()
															})
														) : ''
													),
													el('div', {
															className: 'cwp-list-content-wrap-content-text'
														},
														el(RichText.Content, {
															tagName: 'p',
															value: item.text,
															isSelected: attributes.isSelected,
															style: block_text_style()
														})
													),
													el('div', {
															className: 'cwp-list-content-wrap-meta'
														},
														item.email !== '' && item.email !== undefined ? el('div', {
																className: 'cwp-list-content-wrap-meta-second'
															},
															el('i', {
																className: 'fa fa-envelope'
															}),
															el('a', {
																href: 'mailto:' + item.email,
																style: block_text_style()
															}, item.email)
														) : '',
														item.phone !== '' && item.phone !== undefined ? el('div', {
																className: 'cwp-list-content-wrap-meta-second'
															},
															el('i', {
																className: 'fa fa-phone'
															}),
															el('a', {
																href: 'tel:' + item.phone,
																style: block_text_style()
															}, item.phone)
														) : ''
													),
													(item.buttonURL !== '' && item.buttonText.length > 0 && item.buttonText !== '') || (item.buttonAltURL !== '' && item.buttonAltText.length > 0 && item.buttonAltText !== '') ? el('div', {
															className: 'cwp-buttons-wrap'
														},
														item.buttonURL !== '' && item.buttonText.length > 0 && item.buttonText !== '' ? el('div', {
																className: 'cwp-button-wrap'
															},
															el(RichText.Content, {
																tagName: 'a',
																value: item.buttonText,
																className: item.buttonStyle,
																href: item.buttonURL,
																target: item.buttonTarget,
																rel: item.buttonTarget ? 'noopener noreferrer' : null
															})
														) : '',
														item.buttonAltURL !== '' && item.buttonAltText.length > 0 && item.buttonAltText !== '' ? el('div', {
																className: 'cwp-button-wrap'
															},
															el(RichText.Content, {
																tagName: 'a',
																value: item.buttonAltText,
																className: item.buttonAltStyle,
																href: item.buttonAltURL,
																target: item.buttonAltTarget,
																rel: item.buttonAltTarget ? 'noopener noreferrer' : null
															})
														) : ''
													) : ''
												)
											)
										)
									)
								)
							);
						})
					)
				)
			);
        }
    });
})(
    window.wp
);