(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.editor.InspectorControls;
    var RichText = wp.editor.RichText;
    var Fragment = wp.element.Fragment;
    var MediaUpload = wp.editor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
    var __ = wp.i18n.__;

    wp.blocks.registerBlockType('cwp/title-intro', {
        title: __('Title & Intro', 'cosmic-blocks'),
		keywords: [
			'title & intro',
			__('title', 'cosmic-blocks'),
			__('subtitle', 'cosmic-blocks')
		],
        icon: {
			background: "#16A3FF",
			foreground: "#FFFFFF",
			src: "editor-textcolor"
		},
        category: 'cwp-blocks',
        attributes: {
			blockID: {
				type: 'string',
				default: ''
			},
            columns: {
                type: "number",
                default: 1
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
            backgroundType: {
                type: "string",
                default: 'color'
            },
            backgroundTextColor: {
                type: "string",
                default: ''
            },
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
            paddingBeforeIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterItems: {
                type: 'number',
                default: 50
            },
			introsection: {
                type: 'string',
                default: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            }
        },
        getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
            var attributes = props.attributes;
			
			// override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				attributes.introsection = 'enabled';
			}
			
            var solidColorPreset = el(ColorPalette, {
				value: attributes.solidColor,
				onChange: function(e) {
					props.setAttributes({
						solidColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#00d1b2",
					name: "teal"
				}, {
					color: "#3373dc",
					name: "royal blue"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var backgroundTextColorPreset = el(ColorPalette, {
				value: attributes.backgroundTextColor,
				onChange: function(e) {
					props.setAttributes({
						backgroundTextColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#333333",
					name: "dark"
				}, {
					color: "#000000",
					name: "black"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var gradientPreset = el(SelectControl, {
				label: __('Gradients', 'cosmic-blocks'),
				options: gradient_options.map(function(e) {
					return {
						value: e.colors,
						label: e.name
					};
				}),
				value: attributes.gradient,
				onChange: function(e) {
					props.setAttributes({
						gradient: e
					});
				}
			});
			var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return [
                el(
                    Fragment,
                    null,
                    el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
                        el(wp.components.PanelBody, {
								title: __('Intro', 'cosmic-blocks'),
								className: 'cwp-inspector-intro',
								initialOpen: true
							},
							el('p', {}, __('Intro text color', 'cosmic-blocks')),
							backgroundTextColorPreset,
							el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
							el(RangeControl, {
								label: __('Padding bottom', 'cosmic-blocks'),
								value: attributes.paddingAfterItems,
								allowReset: false,
								initialPosition: 50,
								onChange: function(e) {
									return props.setAttributes({
										paddingAfterItems: e
									});
								},
								min: -1,
								max: 200
							}),
							el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
						),
                        el(wp.components.PanelBody, {
                                title: __('Animation', 'cosmic-blocks'),
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el(SelectControl, {
                                label: __('Animation', 'cosmic-blocks'),
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el(TextControl, {
                                label: __('Animation Delay', 'cosmic-blocks'),
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: __('Enter in milliseconds', 'cosmic-blocks')
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
                                allowReset: false,
                                initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            })
                        )
                    ),
                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-backend-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
                                style: box_padding()
                            },
                            el('div', {
                                    className: 'cwp-main-intro'
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        }),
                                    ),
                                )
                            )
                        )
                    ),

                    /************* FRONT VIEW *************/

                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-front-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner',
                                style: box_padding(),
                                "data-scroll-class": attributes.animationStyle,
                                "data-scroll-delay": attributes.animationDelay,
                                "data-scroll-threshold": attributes.threshold
                            },
                            (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) || (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                    className: 'cwp-main-intro'
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('h3', {
                                            style: back_text_style()
                                        },
                                        attributes.introtitle !== '' ? el(
                                            RichText.Content, {
                                                tagName: '',
                                                value: attributes.introtitle
                                            }
                                        ) : '',
                                        attributes.introsubtitle !== '' ? el(
                                            RichText.Content, {
                                                tagName: 'span',
                                                value: attributes.introsubtitle
                                            }
                                        ) : ''
                                    )
                                ) : '',
                                attributes.introduction !== '' ? el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(
                                            RichText.Content, {
                                                tagName: 'p',
                                                value: attributes.introduction,
                                                style: back_text_style()
                                            }
                                        )
                                    )
                                ) : ''
                            ) : ''
                        )
                    )
                )
            ];
        },
        save: function(props) {
            var attributes = props.attributes;
            var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return el('div', {
					id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                    className: 'cwp-common-main-wrap ' + attributes.container + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                    style: back_style()
                },
                el('div', {
                        className: 'cwp-common-main-wrap-inner',
                        style: box_padding(),
                        "data-scroll-class": attributes.animationStyle,
                        "data-scroll-delay": attributes.animationDelay,
                        "data-scroll-threshold": attributes.threshold
                    },
                    (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) || (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                            className: 'cwp-main-intro'
                        },
                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                className: 'cwp-intro-title'
                            },
                            el('h3', {
                                    style: back_text_style()
                                },
                                attributes.introtitle !== '' ? el(
                                    RichText.Content, {
                                        tagName: '',
                                        value: attributes.introtitle
                                    }
                                ) : '',
                                attributes.introsubtitle !== '' ? el(
                                    RichText.Content, {
                                        tagName: 'span',
                                        value: attributes.introsubtitle
                                    }
                                ) : ''
                            )
                        ) : '',
                        attributes.introduction !== '' ? el('div', {
                                className: 'cwp-intro-introduction'
                            },
                            el('div', {
                                    className: 'cwp-intro-input'
                                },
                                el(
                                    RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.introduction,
                                        style: back_text_style()
                                    }
                                )
                            )
                        ) : ''
                    ) : ''
                )
            );
        }
    });
})(
    window.wp
);